@@ -25,27 +25,32 @@
 #include "kcomboboxdialog.h"
 
 #include <QCheckBox>
+#include <QDialogButtonBox>
 #include <QLabel>
+#include <QPushButton>
 #include <QVBoxLayout>
+#include <KConfigGroup>
 #include <KHistoryComboBox>
 #include <KLocalizedString>
 
 KComboBoxDialog::KComboBoxDialog( const QString &_text, const QStringList &_items, const QString& _value, bool showDontAskAgain, QWidget *parent )
-	: KDialog( parent)
+	: QDialog( parent)
 {
-	setButtons(Ok);
-	setDefaultButton(Ok);
+	auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+	auto mainLayout = new QVBoxLayout(this);
+	auto okButton = buttonBox->button(QDialogButtonBox::Ok);
+	okButton->setDefault(true);
+	okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &KComboBoxDialog::accept);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &KComboBoxDialog::reject);
+
 	setModal(true);
-	showButtonSeparator(true);
-	QFrame *frame = new QFrame(this);
-	setMainWidget(frame);
+	QFrame *frame = new QFrame( this );
 	QVBoxLayout *topLayout = new QVBoxLayout( frame );
-        topLayout->setMargin( marginHint() );
-        topLayout->setSpacing( spacingHint() );
 	QLabel *label = new QLabel(_text, frame );
 	topLayout->addWidget( label, 1 );
 
-	combo = new KHistoryComboBox( frame);
+	combo = new KHistoryComboBox( frame );
 	combo->setEditable(false);
 	combo->addItems( _items );
 	topLayout->addWidget( combo, 1 );
@@ -61,6 +66,14 @@ KComboBoxDialog::KComboBoxDialog( const QString &_text, const QStringList &_item
 	if ( !_value.isNull() )
 		combo->setCurrentItem( _value );
 	combo->setFocus();
+    
+	QFrame* separationLine = new QFrame();
+	separationLine->setFrameShape(QFrame::HLine);
+	separationLine->setFrameShadow(QFrame::Sunken);
+
+	mainLayout->addWidget( frame );
+	mainLayout->addWidget( separationLine );
+	mainLayout->addWidget( buttonBox );
 }
 
 KComboBoxDialog::~KComboBoxDialog()
@@ -98,15 +111,15 @@ QString KComboBoxDialog::getItem( const QString &_text, const QString &_caption,
 				return prevAnswer;
 	}
 
-	KComboBoxDialog dlg( _text, _items, _value, !dontAskAgainName.isNull(), parent );
+	QPointer<KComboBoxDialog> dlg = new KComboBoxDialog( _text, _items, _value, !dontAskAgainName.isNull(), parent );
 	if ( !_caption.isNull() )
-		dlg.setCaption( _caption );
+		dlg->setWindowTitle( _caption );
 
-	dlg.exec();
+	dlg->exec();
 
-	const QString text = dlg.text();
+	const QString text = dlg->text();
 
-	if (dlg.dontAskAgainChecked())
+	if (dlg->dontAskAgainChecked())
 	{
 		if ( !dontAskAgainName.isEmpty() && !text.isEmpty() )
 		{
@@ -115,6 +128,7 @@ QString KComboBoxDialog::getItem( const QString &_text, const QString &_caption,
 			configGroup->writeEntry( dontAskAgainName, text );
 		}
 	}
+	delete dlg;
 
 	return text;
 }
@@ -122,15 +136,15 @@ QString KComboBoxDialog::getItem( const QString &_text, const QString &_caption,
 QString KComboBoxDialog::getText(const QString &_caption, const QString &_text, const QString &_value, bool *ok, QWidget *parent, const QString &configName, KSharedConfigPtr config)
 {
 	KConfigGroup *configGroup = 0;
-	KComboBoxDialog dlg(_text, QStringList(), _value, false, parent);
+	QPointer<KComboBoxDialog> dlg = new KComboBoxDialog(_text, QStringList(), _value, false, parent);
 	if ( !_caption.isNull() )
-		dlg.setCaption( _caption );
+		dlg->setWindowTitle( _caption );
 
-	KHistoryComboBox * const box = dlg.comboBox();
+	KHistoryComboBox * const box = dlg->comboBox();
 	box->setEditable(true);
 
-	const QString historyItem = QString("%1History").arg(configName);
-	const QString completionItem = QString("%1Completion").arg(configName);
+	const QString historyItem = QStringLiteral("%1History").arg(configName);
+	const QString completionItem = QStringLiteral("%1Completion").arg(configName);
 
 	if(!configName.isNull())
 	{
@@ -139,19 +153,19 @@ QString KComboBoxDialog::getText(const QString &_caption, const QString &_text,
 		box->completionObject()->setItems(configGroup->readEntry(completionItem,QStringList()));
 	}
 
-	bool result = dlg.exec();
+	bool result = dlg->exec();
 	if(ok) *ok = result;
 
 	if(!configName.isNull() && result)
 	{
-		box->addToHistory(dlg.text());
-		box->completionObject()->addItem(dlg.text());
+		box->addToHistory(dlg->text());
+		box->completionObject()->addItem(dlg->text());
 		configGroup = new KConfigGroup(config->group("KComboBoxDialog"));
 		configGroup->writeEntry(historyItem, box->historyItems());
 		configGroup->writeEntry(completionItem, box->completionObject()->items());
 	}
 
-	return dlg.text();
+	QString text = dlg->text();
+	delete dlg;
+	return text;
 }
-
-
